/* LICENSE BLOCK
Part of mde: a Modular D game-oriented Engine
Copyright © 2007-2008 Diggory Hardy

This program is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation, either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */

module mde.gui.IGui;

/** The Gui interface.
*
* This contains the functions for use by Windows, not those for external use (use Gui directly for
* that). */
interface IGui
{
    /**  Get the GUI's rendererName for creating a renderer (may be overridden by the window). */
    char[] rendererName ();
    
    /** Called by a sub-widget when a redraw is necessary (since drawing may sometimes be done on
    * event.
    *
    * Currently forces the whole Gui to be redrawn. */
    void requestRedraw ();
    
    /** Add a mouse click callback: delegate will be called for all mouse click events recieved.
     *
     * The delegate should return true if it accepts the event and no further processing is
     * required (i.e. the event should not be handled by anything else), false otherwise.
     * Note that this is not a mechanism to prevent unwanted event handling, and in the future may
     * be removed (so event handling cannot be cut short). */
    void addClickCallback (bool delegate (ushort cx, ushort cy, ubyte b, bool state) dg);
    /** Add a mouse motion callback: delegate will be called for all motion events recieved. */
    void addMotionCallback (void delegate (ushort cx, ushort cy) dg);
    /** Remove all event callbacks with _frame pointer frame. */
    void removeCallbacks (void* frame);
}
